# -*- coding: utf-8 -*-

"""
lassie.exceptions
~~~~~~~~~~~~~~~~~

This module contains the set of Lassie exceptions.

"""

class LassieError(Exception):
    """Generic catch-all Exceptions"""
    pass
